@@ -7,16 +7,14 @@ import logging
 
 from matplotlib import rcParams
 
-from .maxent import maxent
-from .ppa import ppa
-from .roulette import roulette
-from .quartile import quartile
-from .mle import mle
 from .distributions import *
+from .predictive import *
+from .unidimensional import *
+
 
 __all__ = ["maxent", "mle", "ppa", "roulette", "quartile"]
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 
 _log = logging.getLogger("preliz")
 
