@@ -18,9 +18,11 @@ all_continuous = [
     Laplace,
     Logistic,
     LogNormal,
+    LogitNormal,
     Moyal,
     Normal,
     Pareto,
+    Rice,
     SkewNormal,
     Student,
     Triangular,
@@ -30,7 +32,17 @@ all_continuous = [
     Wald,
     Weibull,
 ]
-all_discrete = [Binomial, DiscreteUniform, NegativeBinomial, Poisson]
+all_discrete = [
+    Bernoulli,
+    BetaBinomial,
+    Binomial,
+    Categorical,
+    DiscreteUniform,
+    Geometric,
+    NegativeBinomial,
+    Poisson,
+    ZeroInflatedPoisson,
+]
 
 
 __all__ = [s.__name__ for s in all_continuous] + [s.__name__ for s in all_discrete]
