@@ -10,9 +10,10 @@ from copy import copy
 import numpy as np
 from scipy import stats
 from scipy.special import gamma as gammaf
+from scipy.special import logit, expit  # pylint: disable=no-name-in-module
 
-from ..utils.optimization import optimize_ml
-from ..utils.utils import garcia_approximation
+from ..internal.optimization import optimize_ml
+from ..internal.distribution_helper import garcia_approximation, all_not_none
 from .distributions import Continuous
 
 eps = np.finfo(float).eps
@@ -62,7 +63,7 @@ class AsymmetricLaplace(Continuous):
     Variance  :math:`\frac{1+\kappa^{4}}{b^2\kappa^2 }`
     ========  ========================
 
-    AsymmetricLaplace distribution has 2 alternative parametrizarions. In terms of kappa,
+    AsymmetricLaplace distribution has 2 alternative parametrizations. In terms of kappa,
     mu and b or q, mu and b.
 
     The link between the 2 alternatives is given by
@@ -118,14 +119,14 @@ class AsymmetricLaplace(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(kappa=self.kappa, loc=self.mu, scale=self.b)
         return frozen
 
     def _update(self, kappa, mu, b):
-        self.kappa = float(kappa)
-        self.mu = float(mu)
-        self.b = float(b)
+        self.kappa = np.float64(kappa)
+        self.mu = np.float64(mu)
+        self.b = np.float64(b)
         self.q = self._to_q(self.kappa)
 
         if self.param_names[0] == "kappa":
@@ -260,13 +261,13 @@ class Beta(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.alpha, self.beta)
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = float(alpha)
-        self.beta = float(beta)
+        self.alpha = np.float64(alpha)
+        self.beta = np.float64(beta)
         self.mu, self.sigma = self._to_mu_sigma(self.alpha, self.beta)
         self.kappa = self.mu * (1 - self.mu) / self.sigma**2 - 1
 
@@ -351,18 +352,18 @@ class BetaScaled(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if self.alpha is not None or self.beta is not None:
+        if all_not_none(self):
             frozen = self.dist(self.alpha, self.beta, loc=self.lower, scale=self.upper - self.lower)
         return frozen
 
     def _update(self, alpha, beta, lower=None, upper=None):
         if lower is not None:
-            self.lower = float(lower)
+            self.lower = np.float64(lower)
         if upper is not None:
-            self.upper = float(upper)
+            self.upper = np.float64(upper)
 
-        self.alpha = float(alpha)
-        self.beta = float(beta)
+        self.alpha = np.float64(alpha)
+        self.beta = np.float64(beta)
         self.params = (self.alpha, self.beta, self.lower, self.upper)
         self.support = self.lower, self.upper
         self._update_rv_frozen()
@@ -433,13 +434,13 @@ class Cauchy(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.alpha, self.beta)
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = float(alpha)
-        self.beta = float(beta)
+        self.alpha = np.float64(alpha)
+        self.beta = np.float64(beta)
         self.params = (self.alpha, self.beta)
         self._update_rv_frozen()
 
@@ -504,12 +505,12 @@ class ChiSquared(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.nu)
         return frozen
 
     def _update(self, nu):
-        self.nu = float(nu)
+        self.nu = np.float64(nu)
         self.params = (self.nu,)
         self._update_rv_frozen()
 
@@ -592,9 +593,9 @@ class ExGaussian(Continuous):
         return frozen
 
     def _update(self, mu, sigma, nu):
-        self.nu = float(nu)
-        self.mu = float(mu)
-        self.sigma = float(sigma)
+        self.nu = np.float64(nu)
+        self.mu = np.float64(mu)
+        self.sigma = np.float64(sigma)
         self.params = (self.mu, self.sigma, self.nu)
         self._update_rv_frozen()
 
@@ -656,12 +657,12 @@ class Exponential(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(scale=1 / self.lam)
         return frozen
 
     def _update(self, lam):
-        self.lam = float(lam)
+        self.lam = np.float64(lam)
         self.params = (self.lam,)
         self._update_rv_frozen()
 
@@ -766,13 +767,13 @@ class Gamma(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(a=self.alpha, scale=1 / self.beta)
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = float(alpha)
-        self.beta = float(beta)
+        self.alpha = np.float64(alpha)
+        self.beta = np.float64(beta)
         self.mu, self.sigma = self._to_mu_sigma(self.alpha, self.beta)
 
         if self.param_names[0] == "alpha":
@@ -849,13 +850,13 @@ class Gumbel(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(loc=self.mu, scale=self.beta)
         return frozen
 
     def _update(self, mu, beta):
-        self.mu = float(mu)
-        self.beta = float(beta)
+        self.mu = np.float64(mu)
+        self.beta = np.float64(beta)
         self.params = (self.mu, self.beta)
         self._update_rv_frozen()
 
@@ -917,12 +918,12 @@ class HalfCauchy(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(scale=self.beta)
         return frozen
 
     def _update(self, beta):
-        self.beta = float(beta)
+        self.beta = np.float64(beta)
         self.params = (self.beta,)
         self._update_rv_frozen()
 
@@ -1003,12 +1004,12 @@ class HalfNormal(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(scale=self.sigma)
         return frozen
 
     def _update(self, sigma):
-        self.sigma = float(sigma)
+        self.sigma = np.float64(sigma)
         self.tau = to_precision(sigma)
 
         if self.param_names[0] == "sigma":
@@ -1111,13 +1112,13 @@ class HalfStudent(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if all(self.params):
+        if all_not_none(self):
             frozen = self.dist(nu=self.nu, sigma=self.sigma)
         return frozen
 
     def _update(self, nu, sigma):
-        self.nu = float(nu)
-        self.sigma = float(sigma)
+        self.nu = np.float64(nu)
+        self.sigma = np.float64(sigma)
         self.lam = to_precision(sigma)
 
         if self.param_names[1] == "sigma":
@@ -1152,7 +1153,7 @@ class HalfStudent(Continuous):
         optimize_ml(self, sample)
 
 
-class _HalfStudent(stats._distn_infrastructure.rv_continuous):
+class _HalfStudent(stats.rv_continuous):
     def __init__(self, nu=None, sigma=None):
         super().__init__()
         self.nu = nu
@@ -1307,13 +1308,13 @@ class InverseGamma(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(a=self.alpha, scale=self.beta)
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = float(alpha)
-        self.beta = float(beta)
+        self.alpha = np.float64(alpha)
+        self.beta = np.float64(beta)
         self.mu, self.sigma = self._to_mu_sigma(self.alpha, self.beta)
 
         if self.param_names[0] == "alpha":
@@ -1385,13 +1386,13 @@ class Laplace(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(loc=self.mu, scale=self.b)
         return frozen
 
     def _update(self, mu, b):
-        self.mu = float(mu)
-        self.b = float(b)
+        self.mu = np.float64(mu)
+        self.b = np.float64(b)
         self.params = (self.mu, self.b)
         self._update_rv_frozen()
 
@@ -1407,38 +1408,38 @@ class Laplace(Continuous):
 
 class Logistic(Continuous):
     r"""
-     Logistic distribution.
+    Logistic distribution.
 
-     The pdf of this distribution is
+    The pdf of this distribution is
 
-     .. math::
+    .. math::
 
-        f(x \mid \mu, s) =
-            \frac{\exp\left(-\frac{x - \mu}{s}\right)}
-            {s \left(1 + \exp\left(-\frac{x - \mu}{s}\right)\right)^2}
+    f(x \mid \mu, s) =
+        \frac{\exp\left(-\frac{x - \mu}{s}\right)}
+        {s \left(1 + \exp\left(-\frac{x - \mu}{s}\right)\right)^2}
 
-     .. plot::
-         :context: close-figs
+    .. plot::
+        :context: close-figs
 
-         import arviz as az
-         from preliz import Logistic
-         az.style.use('arviz-white')
-         mus = [0., 0., -2.]
-         ss = [1., 2., .4]
-         for mu, s in zip(mus, ss):
-             Logistic(mu, s).plot_pdf(support=(-5,5))
+        import arviz as az
+        from preliz import Logistic
+        az.style.use('arviz-white')
+        mus = [0., 0., -2.]
+        ss = [1., 2., .4]
+        for mu, s in zip(mus, ss):
+            Logistic(mu, s).plot_pdf(support=(-5,5))
 
-    ========  ==========================================
+    =========  ==========================================
      Support   :math:`x \in \mathbb{R}`
      Mean      :math:`\mu`
      Variance  :math:`\frac{s^2 \pi^2}{3}`
-     ========  ==========================================
+    =========  ==========================================
 
-     Parameters
-     ----------
-     mu : float
+    Parameters
+    ----------
+    mu : float
         Mean.
-     s : float
+    s : float
         Scale (s > 0).
     """
 
@@ -1459,13 +1460,13 @@ class Logistic(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(loc=self.mu, scale=self.s)
         return frozen
 
     def _update(self, mu, s):
-        self.mu = float(mu)
-        self.s = float(s)
+        self.mu = np.float64(mu)
+        self.s = np.float64(s)
         self.params = (self.mu, self.s)
         self._update_rv_frozen()
 
@@ -1538,13 +1539,13 @@ class LogNormal(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.sigma, scale=np.exp(self.mu))
         return frozen
 
     def _update(self, mu, sigma):
-        self.mu = float(mu)
-        self.sigma = float(sigma)
+        self.mu = np.float64(mu)
+        self.sigma = np.float64(sigma)
         self.params = (self.mu, self.sigma)
         self._update_rv_frozen()
 
@@ -1558,6 +1559,154 @@ class LogNormal(Continuous):
         self._update(np.log(mu), sigma)
 
 
+class LogitNormal(Continuous):
+    r"""
+    Logit-Normal log-likelihood.
+
+    The pdf of this distribution is
+
+    .. math::
+       f(x \mid \mu, \tau) =
+           \frac{1}{x(1-x)} \sqrt{\frac{\tau}{2\pi}}
+           \exp\left\{ -\frac{\tau}{2} (logit(x)-\mu)^2 \right\}
+
+
+    .. plot::
+        :context: close-figs
+
+        import arviz as az
+        from preliz import LogitNormal
+        az.style.use('arviz-white')
+        mus = [0., 0., 0., 1.]
+        sigmas = [0.3, 1., 2., 1.]
+        for mu, sigma in zip(mus, sigmas):
+            LogitNormal(mu, sigma).plot_pdf()
+
+    ========  ==========================================
+    Support   :math:`x \in (0, 1)`
+    Mean      no analytical solution
+    Variance  no analytical solution
+    ========  ==========================================
+
+    Parameters
+    ----------
+    mu : float
+        Location parameter.
+    sigma : float
+        Scale parameter (sigma > 0).
+    tau : float
+        Scale parameter (tau > 0).
+    """
+
+    def __init__(self, mu=None, sigma=None, tau=None):
+        super().__init__()
+        self.dist = _LogitNormal
+        self.support = (0, 1)
+        self._parametrization(mu, sigma, tau)
+
+    def _parametrization(self, mu=None, sigma=None, tau=None):
+        if sigma is not None and tau is not None:
+            raise ValueError(
+                "Incompatible parametrization. Either use mu and sigma, or mu and tau."
+            )
+
+        names = ("mu", "sigma")
+        self.params_support = ((-np.inf, np.inf), (eps, np.inf))
+
+        if tau is not None:
+            self.tau = tau
+            sigma = from_precision(tau)
+            names = ("mu", "tau")
+
+        self.mu = mu
+        self.sigma = sigma
+        self.param_names = names
+        if mu is not None and sigma is not None:
+            self._update(mu, sigma)
+
+    def _get_frozen(self):
+        frozen = None
+        if all_not_none(self):
+            frozen = self.dist(self.mu, self.sigma)
+        return frozen
+
+    def _update(self, mu, sigma):
+        self.mu = np.float64(mu)
+        self.sigma = np.float64(sigma)
+        self.tau = to_precision(sigma)
+
+        if self.param_names[1] == "sigma":
+            self.params = (self.mu, self.sigma)
+        elif self.param_names[1] == "tau":
+            self.params = (self.mu, self.tau)
+
+        self._update_rv_frozen()
+
+    def _fit_moments(self, mean, sigma):
+        mu = logit(mean)
+        sigma = np.diff((mean - sigma * 3, mean + sigma * 3))
+        self._update(mu, sigma)
+
+    def _fit_mle(self, sample, **kwargs):
+        mu, sigma = stats.norm.fit(logit(sample), **kwargs)
+        self._update(mu, sigma)
+
+
+class _LogitNormal(stats.rv_continuous):
+    def __init__(self, mu=None, sigma=None):
+        super().__init__()
+        self.mu = mu
+        self.sigma = sigma
+
+    def support(self, *args, **kwd):  # pylint: disable=unused-argument
+        return (0, 1)
+
+    def cdf(self, x, *args, **kwds):
+        return stats.norm(self.mu, self.sigma, *args, **kwds).cdf(logit(x))
+
+    def pdf(self, x, *args, **kwds):
+        x = np.asarray(x)
+        mask = np.logical_or(x == 0, x == 1)
+        result = np.zeros_like(x, dtype=float)
+        result[~mask] = stats.norm(self.mu, self.sigma, *args, **kwds).pdf(logit(x[~mask])) / (
+            x[~mask] * (1 - x[~mask])
+        )
+        return result
+
+    def logpdf(self, x, *args, **kwds):
+        x = np.asarray(x)
+        mask = np.logical_or(x == 0, x == 1)
+        result = np.full_like(x, -np.inf, dtype=float)
+        result[~mask] = (
+            stats.norm(self.mu, self.sigma, *args, **kwds).logpdf(logit(x[~mask]))
+            - np.log(x[~mask])
+            - np.log1p(-x[~mask])
+        )
+        return result
+
+    def ppf(self, q, *args, **kwds):
+        x_vals = np.linspace(0, 1, 1000)
+        idx = np.searchsorted(self.cdf(x_vals[:-1], *args, **kwds), q)
+        return x_vals[idx]
+
+    def _stats(self, *args, **kwds):  # pylint: disable=unused-argument
+        # https://en.wikipedia.org/wiki/Logit-normal_distribution#Moments
+        norm = stats.norm(self.mu, self.sigma)
+        logistic_inv = expit(norm.ppf(np.linspace(0, 1, 100000)))
+        mean = np.mean(logistic_inv)
+        var = np.var(logistic_inv)
+        return (mean, var, np.nan, np.nan)
+
+    def entropy(self):  # pylint: disable=arguments-differ
+        moments = self._stats()
+        return stats.norm(moments[0], moments[1] ** 0.5).entropy()
+
+    def rvs(
+        self, size=1, random_state=None
+    ):  # pylint: disable=arguments-differ, disable=unused-argument
+        return expit(np.random.normal(self.mu, self.sigma, size))
+
+
 class Moyal(Continuous):
     r"""
     Moyal distribution.
@@ -1618,13 +1767,13 @@ class Moyal(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(loc=self.mu, scale=self.sigma)
         return frozen
 
     def _update(self, mu, sigma):
-        self.mu = float(mu)
-        self.sigma = float(sigma)
+        self.mu = np.float64(mu)
+        self.sigma = np.float64(sigma)
         self.params = (self.mu, self.sigma)
         self._update_rv_frozen()
 
@@ -1714,13 +1863,13 @@ class Normal(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.mu, self.sigma)
         return frozen
 
     def _update(self, mu, sigma):
-        self.mu = float(mu)
-        self.sigma = float(sigma)
+        self.mu = np.float64(mu)
+        self.sigma = np.float64(sigma)
         self.tau = to_precision(sigma)
 
         if self.param_names[1] == "sigma":
@@ -1790,13 +1939,13 @@ class Pareto(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.alpha, scale=self.m)
         return frozen
 
     def _update(self, alpha, m):
-        self.alpha = float(alpha)
-        self.m = float(m)
+        self.alpha = np.float64(alpha)
+        self.m = np.float64(m)
         self.support = (self.m, np.inf)
         self.params = (self.alpha, self.m)
         self._update_rv_frozen()
@@ -1811,6 +1960,120 @@ class Pareto(Continuous):
         self._update(alpha, m)
 
 
+class Rice(Continuous):
+    r"""
+    Rice distribution.
+
+    The pdf of this distribution is
+
+    .. math::
+
+        f(x\mid \nu ,\sigma )=
+            {\frac  {x}{\sigma ^{2}}}\exp
+            \left({\frac  {-(x^{2}+\nu ^{2})}
+            {2\sigma ^{2}}}\right)I_{0}\left({\frac  {x\nu }{\sigma ^{2}}}\right)
+
+    .. plot::
+        :context: close-figs
+
+        import arviz as az
+        from preliz import Rice
+        az.style.use('arviz-white')
+        nus = [0., 0., 4.]
+        sigmas = [1., 2., 2.]
+        for nu, sigma in  zip(nus, sigmas):
+            Rice(nu, sigma).plot_pdf(support=(0,10))
+
+    ========  ==============================================================
+    Support   :math:`x \in (0, \infty)`
+    Mean      :math:`\sigma {\sqrt  {\pi /2}}\,\,L_{{1/2}}(-\nu ^{2}/2\sigma ^{2})`
+    Variance  :math:`2\sigma ^{2}+\nu ^{2}-{\frac  {\pi \sigma ^{2}}{2}}L_{{1/2}}^{2}
+                        \left({\frac  {-\nu ^{2}}{2\sigma ^{2}}}\right)`
+    ========  ==============================================================
+
+    Rice distribution has 2 alternative parameterizations. In terms of nu and sigma
+    or b and sigma.
+
+    The link between the two parametrizations is given by
+
+    .. math::
+
+       b = \dfrac{\nu}{\sigma}
+
+    Parameters
+    ----------
+    nu : float
+        Noncentrality parameter.
+    sigma : float
+        Scale parameter.
+    b : float
+        Shape parameter.
+    """
+
+    def __init__(self, nu=None, sigma=None, b=None):
+        super().__init__()
+        self.name = "rice"
+        self.dist = copy(stats.rice)
+        self.support = (0, np.inf)
+        self._parametrization(nu, sigma, b)
+
+    def _parametrization(self, nu=None, sigma=None, b=None):
+        if nu is not None and b is not None:
+            raise ValueError(
+                "Incompatible parametrization. Either use nu and sigma or b and sigma."
+            )
+
+        self.param_names = ("nu", "sigma")
+        self.params_support = ((eps, np.inf), (eps, np.inf))
+
+        if b is not None:
+            self.b = b
+            self.sigma = sigma
+            self.param_names = ("b", "sigma")
+            if (b and sigma) is not None:
+                nu = self._from_b(b, sigma)
+
+        self.nu = nu
+        self.sigma = sigma
+        if self.nu is not None and self.sigma is not None:
+            self._update(self.nu, self.sigma)
+
+    def _from_b(self, b, sigma):
+        nu = b * sigma
+        return nu
+
+    def _to_b(self, nu, sigma):
+        b = nu / sigma
+        return b
+
+    def _get_frozen(self):
+        frozen = None
+        if all_not_none(self):
+            b_ = self._to_b(self.nu, self.sigma)
+            frozen = self.dist(b=b_, scale=self.sigma)
+        return frozen
+
+    def _update(self, nu, sigma):
+        self.nu = np.float64(nu)
+        self.sigma = np.float64(sigma)
+        self.b = self._to_b(self.nu, self.sigma)
+
+        if self.param_names[0] == "nu":
+            self.params = (self.nu, self.sigma)
+        elif self.param_names[0] == "b":
+            self.params = (self.b, self.sigma)
+
+        self._update_rv_frozen()
+
+    def _fit_moments(self, mean, sigma):
+        self._update(mean, sigma)
+
+    def _fit_mle(self, sample, **kwargs):
+        b, _, sigma = self.dist.fit(sample, **kwargs)
+        nu = self._from_b(b, sigma)
+        self._update(nu, sigma)
+
+
 class SkewNormal(Continuous):
     r"""
     SkewNormal distribution.
@@ -1893,14 +2156,14 @@ class SkewNormal(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.alpha, self.mu, self.sigma)
         return frozen
 
     def _update(self, mu, sigma, alpha):
-        self.mu = float(mu)
-        self.sigma = float(sigma)
-        self.alpha = float(alpha)
+        self.mu = np.float64(mu)
+        self.sigma = np.float64(sigma)
+        self.alpha = np.float64(alpha)
         self.tau = to_precision(sigma)
 
         if self.param_names[1] == "sigma":
@@ -2004,14 +2267,14 @@ class Student(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.nu, self.mu, self.sigma)
         return frozen
 
     def _update(self, nu, mu, sigma):
-        self.nu = float(nu)
-        self.mu = float(mu)
-        self.sigma = float(sigma)
+        self.nu = np.float64(nu)
+        self.mu = np.float64(mu)
+        self.sigma = np.float64(sigma)
         self.lam = to_precision(sigma)
 
         if self.param_names[2] == "sigma":
@@ -2103,16 +2366,16 @@ class Triangular(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             scale = self.upper - self.lower
             c_ = (self.c - self.lower) / scale
             frozen = self.dist(c=c_, loc=self.lower, scale=scale)
         return frozen
 
     def _update(self, lower, c, upper):
-        self.lower = float(lower)
-        self.c = float(c)
-        self.upper = float(upper)
+        self.lower = np.float64(lower)
+        self.c = np.float64(c)
+        self.upper = np.float64(upper)
         self.support = (self.lower, self.upper)
         self.params = (self.lower, self.c, self.upper)
         self._update_rv_frozen()
@@ -2209,12 +2472,12 @@ class TruncatedNormal(Continuous):
 
     def _update(self, mu, sigma, lower=None, upper=None):
         if lower is not None:
-            self.lower = float(lower)
+            self.lower = np.float64(lower)
         if upper is not None:
-            self.upper = float(upper)
+            self.upper = np.float64(upper)
 
-        self.mu = float(mu)
-        self.sigma = float(sigma)
+        self.mu = np.float64(mu)
+        self.sigma = np.float64(sigma)
         self.params = (self.mu, self.sigma, self.lower, self.upper)
         self.support = (self.lower, self.upper)
         self._update_rv_frozen()
@@ -2289,13 +2552,13 @@ class Uniform(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.lower, self.upper - self.lower)
         return frozen
 
     def _update(self, lower, upper):
-        self.lower = float(lower)
-        self.upper = float(upper)
+        self.lower = np.float64(lower)
+        self.upper = np.float64(upper)
         self.params = (self.lower, self.upper)
         self.support = (self.lower, self.upper)
         self._update_rv_frozen()
@@ -2365,13 +2628,13 @@ class VonMises(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(kappa=self.kappa, loc=self.mu)
         return frozen
 
     def _update(self, mu, kappa):
-        self.mu = float(mu)
-        self.kappa = float(kappa)
+        self.mu = np.float64(mu)
+        self.kappa = np.float64(kappa)
         self.params = (self.mu, self.kappa)
         self._update_rv_frozen()
 
@@ -2440,13 +2703,13 @@ class Wald(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.mu / self.lam, scale=self.lam)
         return frozen
 
     def _update(self, mu, lam):
-        self.mu = float(mu)
-        self.lam = float(lam)
+        self.mu = np.float64(mu)
+        self.lam = np.float64(lam)
         self.params = (self.mu, self.lam)
         self._update_rv_frozen()
 
@@ -2512,13 +2775,13 @@ class Weibull(Continuous):
 
     def _get_frozen(self):
         frozen = None
-        if any(self.params):
+        if all_not_none(self):
             frozen = self.dist(self.alpha, scale=self.beta)
         return frozen
 
     def _update(self, alpha, beta):
-        self.alpha = float(alpha)
-        self.beta = float(beta)
+        self.alpha = np.float64(alpha)
+        self.beta = np.float64(beta)
         self.params = (self.alpha, self.beta)
         self._update_rv_frozen()
 
