@@ -4,11 +4,22 @@ Parent classes for all families.
 # pylint: disable=no-member
 from collections import namedtuple
 
-from ipywidgets import interact
+from ipywidgets import interactive
 import numpy as np
 
-from ..utils.plot_utils import plot_pdfpmf, plot_cdf, plot_ppf
-from ..utils.utils import hdi_from_pdf, get_slider, init_vals
+from ..internal.plot_helper import (
+    plot_pdfpmf,
+    plot_cdf,
+    plot_ppf,
+    get_slider,
+    check_inside_notebook,
+)
+from ..internal.distribution_helper import (
+    init_vals,
+    valid_scalar_params,
+    valid_distribution,
+    hdi_from_pdf,
+)
 
 
 class Distribution:
@@ -29,8 +40,9 @@ class Distribution:
             bolded_name = "\033[1m" + name + "\033[0m"
 
             description = "".join(
-                f"{n}={v:.2f}," for n, v in zip(self.param_names, self.params)
+                f"{n}={np.round(v, 2)}," for n, v in zip(self.param_names, self.params)
             ).strip(",")
+
             return f"{bolded_name}({description})"
         else:
             return name
@@ -56,7 +68,9 @@ class Distribution:
         mass: float
             Probability mass for the equal-tailed interval. Defaults to 0.94
         """
-        if self.is_frozen:
+        valid_distribution(self)
+
+        if valid_scalar_params(self):
             attr = namedtuple(self.__class__.__name__, ["mean", "median", "std", "lower", "upper"])
             mean = float(f"{self.rv_frozen.mean():{fmt}}")
             median = float(f"{self.rv_frozen.median():{fmt}}")
@@ -111,10 +125,15 @@ class Distribution:
         mass: float
             Probability mass in the interval. Defaults to 0.94
         """
-        eti = self.rv_frozen.interval(mass)
-        lower_tail = float(f"{eti[0]:{fmt}}")
-        upper_tail = float(f"{eti[1]:{fmt}}")
-        return (lower_tail, upper_tail)
+        valid_distribution(self)
+
+        if valid_scalar_params(self):
+            eti = self.rv_frozen.interval(mass)
+            lower_tail = float(f"{eti[0]:{fmt}}")
+            upper_tail = float(f"{eti[1]:{fmt}}")
+            return (lower_tail, upper_tail)
+        else:
+            return None
 
     def hdi(self, fmt=".2f", mass=0.94):
         """Highest density interval containing `mass`.
@@ -127,10 +146,15 @@ class Distribution:
         mass: float
             Probability mass in the interval. Defaults to 0.94
         """
-        hdi = hdi_from_pdf(self, mass)
-        lower_tail = float(f"{hdi[0]:{fmt}}")
-        upper_tail = float(f"{hdi[1]:{fmt}}")
-        return (lower_tail, upper_tail)
+        valid_distribution(self)
+
+        if valid_scalar_params(self):
+            hdi = hdi_from_pdf(self, mass)
+            lower_tail = float(f"{hdi[0]:{fmt}}")
+            upper_tail = float(f"{hdi[1]:{fmt}}")
+            return (lower_tail, upper_tail)
+        else:
+            return None
 
     def _check_endpoints(self, lower, upper, raise_error=True):
         """
@@ -197,7 +221,8 @@ class Distribution:
         self,
         moments=None,
         pointinterval=False,
-        quantiles=None,
+        interval="hdi",
+        levels=None,
         support="full",
         legend="legend",
         figsize=None,
@@ -215,35 +240,37 @@ class Distribution:
         pointinterval : bool
             Whether to include a plot of the quantiles. Defaults to False. If True the default is to
             plot the median and two interquantiles ranges.
-        quantiles : list
-            Values of the five quantiles to use when ``pointinterval=True`` if None (default)
-            the values ``[0.05, 0.25, 0.5, 0.75, 0.95]`` will be used. The number of elements
-            should be 5, 3, 1 or 0 (in this last case nothing will be plotted).
+        interval : str
+            Type of interval. Available options are highest density interval `"hdi"` (default),
+        equal tailed interval `"eti"` or intervals defined by arbitrary `"quantiles"`.
+        levels : list
+            Mass of the intervals. For hdi or eti the number of elements should be 2 or 1.
+            For quantiles the number of elements should be 5, 3, 1 or 0
+            (in this last case nothing will be plotted).
         support : str:
             If ``full`` use the finite end-points to set the limits of the plot. For unbounded
             end-points or if ``restricted`` use the 0.001 and 0.999 quantiles to set the limits.
         legend : str
             Whether to include a string with the distribution and its parameter as a ``"legend"`` a
-            ``"title"`` or not include them ``False``.
+            ``"title"`` or not include them ``None``.
         figsize : tuple
             Size of the figure
         ax : matplotlib axes
         """
-        if self.is_frozen:
+
+        if valid_scalar_params(self):
             return plot_pdfpmf(
-                self, moments, pointinterval, quantiles, support, legend, figsize, ax
+                self, moments, pointinterval, interval, levels, support, legend, figsize, ax
             )
         else:
-            raise ValueError(
-                "Undefined distribution, "
-                "you need to first define its parameters or use one of the fit methods"
-            )
+            return None
 
     def plot_cdf(
         self,
         moments=None,
         pointinterval=False,
-        quantiles=None,
+        interval="hdi",
+        levels=None,
         support="full",
         legend="legend",
         figsize=None,
@@ -261,33 +288,36 @@ class Distribution:
         pointinterval : bool
             Whether to include a plot of the quantiles. Defaults to False. If True the default is to
             plot the median and two interquantiles ranges.
-        quantiles : list
-            Values of the five quantiles to use when ``pointinterval=True`` if None (default)
-            the values ``[0.05, 0.25, 0.5, 0.75, 0.95]`` will be used. The number of elements
-            should be 5, 3, 1 or 0 (in this last case nothing will be plotted).
+        interval : str
+            Type of interval. Available options are highest density interval `"hdi"` (default),
+        equal tailed interval `"eti"` or intervals defined by arbitrary `"quantiles"`.
+        levels : list
+            Mass of the intervals. For hdi or eti the number of elements should be 2 or 1.
+            For quantiles the number of elements should be 5, 3, 1 or 0
+            (in this last case nothing will be plotted).
         support : str:
             If ``full`` use the finite end-points to set the limits of the plot. For unbounded
             end-points or if ``restricted`` use the 0.001 and 0.999 quantiles to set the limits.
         legend : str
             Whether to include a string with the distribution and its parameter as a ``"legend"`` a
-            ``"title"`` or not include them ``False``.
+            ``"title"`` or not include them ``None``.
         figsize : tuple
             Size of the figure
         ax : matplotlib axes
         """
-        if self.is_frozen:
-            return plot_cdf(self, moments, pointinterval, quantiles, support, legend, figsize, ax)
-        else:
-            raise ValueError(
-                "Undefined distribution, "
-                "you need to first define its parameters or use one of the fit methods"
+        if valid_scalar_params(self):
+            return plot_cdf(
+                self, moments, pointinterval, interval, levels, support, legend, figsize, ax
             )
+        else:
+            return None
 
     def plot_ppf(
         self,
         moments=None,
         pointinterval=False,
-        quantiles=None,
+        interval="hdi",
+        levels=None,
         legend="legend",
         figsize=None,
         ax=None,
@@ -304,26 +334,28 @@ class Distribution:
         pointinterval : bool
             Whether to include a plot of the quantiles. Defaults to False. If True the default is to
             plot the median and two interquantiles ranges.
-        quantiles : list
-            Values of the five quantiles to use when ``pointinterval=True`` if None (default)
-            the values ``[0.05, 0.25, 0.5, 0.75, 0.95]`` will be used. The number of elements
-            should be 5, 3, 1 or 0 (in this last case nothing will be plotted).
+        interval : str
+            Type of interval. Available options are highest density interval `"hdi"` (default),
+        equal tailed interval `"eti"` or intervals defined by arbitrary `"quantiles"`.
+        levels : list
+            Mass of the intervals. For hdi or eti the number of elements should be 2 or 1.
+            For quantiles the number of elements should be 5, 3, 1 or 0
+            (in this last case nothing will be plotted).
         legend : str
             Whether to include a string with the distribution and its parameter as a ``"legend"`` a
-            ``"title"`` or not include them ``False``.
+            ``"title"`` or not include them ``None``.
         figsize : tuple
             Size of the figure
         ax : matplotlib axes
         """
-        if self.is_frozen:
-            return plot_ppf(self, moments, pointinterval, quantiles, legend, figsize, ax)
+        if valid_scalar_params(self):
+            return plot_ppf(self, moments, pointinterval, interval, levels, legend, figsize, ax)
         else:
-            raise ValueError(
-                "Undefined distribution, "
-                "you need to first define its parameters or use one of the fit methods"
-            )
+            return None
 
-    def plot_interactive(self, kind="pdf", fixed_lim="both", pointinterval=True, quantiles=None):
+    def plot_interactive(
+        self, kind="pdf", fixed_lim="both", pointinterval=True, interval="hdi", levels=None
+    ):
         """
         Interactive exploration of distributions parameters
 
@@ -340,12 +372,17 @@ class Distribution:
         pointinterval : bool
             Whether to include a plot of the quantiles. Defaults to False. If True the default is to
             plot the median and two interquantiles ranges.
-        quantiles : list
-            Values of the five quantiles to use when ``pointinterval=True`` if None (default)
-            the values ``[0.05, 0.25, 0.5, 0.75, 0.95]`` will be used. The number of elements
-            should be 5, 3, 1 or 0 (in this last case nothing will be plotted).
+        interval : str
+            Type of interval. Available options are highest density interval `"hdi"` (default),
+        equal tailed interval `"eti"` or intervals defined by arbitrary `"quantiles"`.
+        levels : list
+            Mass of the intervals. For hdi or eti the number of elements should be 2 or 1.
+            For quantiles the number of elements should be 5, 3, 1 or 0
+            (in this last case nothing will be plotted).
         """
-        if self.is_frozen:
+        check_inside_notebook()
+
+        if valid_scalar_params(self, check_frozen=False):
             args = dict(zip(self.param_names, self.params))
         else:
             args = init_vals[self.__class__.__name__]
@@ -355,32 +392,55 @@ class Distribution:
         if fixed_lim == "both":
             xlim = self._finite_endpoints("full")
             xvals = self.xvals("restricted")
-            max_pdf = np.max(self.pdf(xvals))
-            ylim = (-max_pdf * 0.075, max_pdf * 1.5)
+            if kind == "pdf":
+                max_pdf = np.max(self.pdf(xvals))
+                ylim = (-max_pdf * 0.075, max_pdf * 1.5)
+            elif kind == "ppf":
+                max_ppf = self.ppf(0.999)
+                ylim = (-max_ppf * 0.075, max_ppf * 1.5)
         elif isinstance(fixed_lim, tuple):
             xlim = fixed_lim[:2]
             ylim = fixed_lim[2:]
 
         sliders = {}
-        for name, value, support in zip(self.param_names, self.params, self.params_support):
-            lower, upper = support
+        if self.__class__.__name__ == "Categorical":
+            pointinterval = False
+            name = self.param_names[0]
+            params = self.params[0]
+            names = [f"{name}_{i}" for i in range(len(params))]
+            supports = [(0, 1) for _ in range(len(params))]
 
-            sliders[name] = get_slider(name, value, lower, upper)
+            for name, value, support in zip(names, params, supports):
+                sliders[name] = get_slider(name, value, *support)
+        else:
+            for name, value, support in zip(self.param_names, self.params, self.params_support):
+                sliders[name] = get_slider(name, value, *support)
 
-        def plot(**args):
+        def plot(**args):  # pylint: disable=inconsistent-return-statements
+            if self.__class__.__name__ == "Categorical":
+                values = list(args.values())
+                args = {list(args.keys())[0].split("_")[0]: values}
+                if np.sum(values) > 1:
+                    return None
             self.__init__(**args)
             if kind == "pdf":
-                ax = self.plot_pdf(legend=False, pointinterval=pointinterval, quantiles=quantiles)
+                ax = self.plot_pdf(
+                    legend=False, pointinterval=pointinterval, interval=interval, levels=levels
+                )
             elif kind == "cdf":
-                ax = self.plot_cdf(legend=False, pointinterval=pointinterval, quantiles=quantiles)
+                ax = self.plot_cdf(
+                    legend=False, pointinterval=pointinterval, interval=interval, levels=levels
+                )
             elif kind == "ppf":
-                ax = self.plot_ppf(legend=False, pointinterval=pointinterval, quantiles=quantiles)
+                ax = self.plot_ppf(
+                    legend=False, pointinterval=pointinterval, interval=interval, levels=levels
+                )
             if fixed_lim != "auto" and kind != "ppf":
                 ax.set_xlim(*xlim)
             if fixed_lim != "auto" and kind != "cdf":
                 ax.set_ylim(*ylim)
 
-        interact(plot, **sliders)
+        return interactive(plot, **sliders)
 
 
 class Continuous(Distribution):
