@@ -22,9 +22,11 @@ from preliz.distributions import (
     Laplace,
     Logistic,
     LogNormal,
+    LogitNormal,
     Moyal,
     Normal,
     Pareto,
+    Rice,
     SkewNormal,
     Student,
     Triangular,
@@ -33,10 +35,14 @@ from preliz.distributions import (
     VonMises,
     Wald,
     Weibull,
+    # Bernoulli, maxent is not useful for Bernoulli distribution as we only have two states
+    BetaBinomial,
     Binomial,
     DiscreteUniform,
+    Geometric,
     NegativeBinomial,
     Poisson,
+    ZeroInflatedPoisson,
 )
 
 
@@ -81,6 +87,8 @@ from preliz.distributions import (
         (Logistic(), -1, 1, 0.5, (-np.inf, np.inf), (0, 0.91)),
         (LogNormal(), 1, 4, 0.5, (0, np.inf), (1.216, 0.859)),
         (LogNormal(mu=1), 1, 4, 0.5, (0, np.inf), (0.978)),
+        (LogitNormal(), 0.3, 0.8, 0.9, (0, 1), (0.226, 0.677)),
+        (LogitNormal(mu=0.7), 0.3, 0.8, 0.9, (0, 1), (0.531)),
         (Moyal(), 0, 10, 0.9, (-np.inf, np.inf), (2.935, 1.6)),
         (Moyal(mu=4), 0, 10, 0.9, (-np.inf, np.inf), (1.445)),
         (Normal(), -1, 1, 0.683, (-np.inf, np.inf), (0, 1)),
@@ -88,6 +96,8 @@ from preliz.distributions import (
         (Normal(mu=0.5), -1, 1, 0.8, (-np.inf, np.inf), (0.581)),
         (Pareto(), 1, 4, 0.9, (1, np.inf), (1.660, 1)),
         (Pareto(m=2), 1, 4, 0.9, (2, np.inf), (3.321)),
+        (Rice(), 0, 4, 0.7, (0, np.inf), (0.027, 2.577)),
+        (Rice(nu=4), 0, 6, 0.9, (0, np.inf), (1.402)),
         (SkewNormal(), -2, 10, 0.9, (-np.inf, np.inf), (3.999, 3.647, 0)),
         (SkewNormal(mu=-1), -2, 10, 0.9, (-np.inf, np.inf), (6.2924, 4.905)),
         (Student(), -1, 1, 0.683, (-np.inf, np.inf), (99.999, 0, 0.994)),
@@ -124,13 +134,18 @@ from preliz.distributions import (
         (Wald(mu=5), 0, 10, 0.9, (0, np.inf), (7.348)),
         (Weibull(), 0, 10, 0.9, (0, np.inf), (1.411, 5.537)),
         (Weibull(alpha=2), 0, 10, 0.9, (0, np.inf), (6.590)),
+        (BetaBinomial(), 2, 8, 0.9, (0, 8), (1.95, 1.344, 8)),
+        (BetaBinomial(n=10), 2, 6, 0.6, (0, 10), (1.837, 2.181)),
         # results for binomial are close to the correct result, but still off
         (Binomial(), 3, 9, 0.9, (0, 9), (9, 0.490)),
         (Binomial(n=12), 3, 9, 0.9, (0, 12), (0.612)),
         (DiscreteUniform(), -2, 10, 0.9, (-3, 11), (-2, 10)),
+        (Geometric(), 1, 4, 0.99, (0, np.inf), (0.6837)),
         (NegativeBinomial(), 0, 15, 0.9, (0, np.inf), (7.546, 2.041)),
         (NegativeBinomial(p=0.2), 0, 15, 0.9, (0, np.inf), (1.847)),
         (Poisson(), 0, 3, 0.7, (0, np.inf), (2.763)),
+        (ZeroInflatedPoisson(), 0, 3, 0.7, (0, np.inf), (1, 2.763)),
+        (ZeroInflatedPoisson(psi=0.8), 0, 3, 0.7, (0, np.inf), (1.898)),
     ],
 )
 def test_maxent(dist, lower, upper, mass, support, result):
