@@ -21,9 +21,11 @@ from preliz.distributions import (
     Laplace,
     Logistic,
     LogNormal,
+    LogitNormal,
     Moyal,
     Normal,
     Pareto,
+    Rice,
     SkewNormal,
     Student,
     Triangular,
@@ -32,10 +34,14 @@ from preliz.distributions import (
     VonMises,
     Wald,
     Weibull,
+    Bernoulli,
+    BetaBinomial,
     Binomial,
     DiscreteUniform,
+    Geometric,
     NegativeBinomial,
     Poisson,
+    ZeroInflatedPoisson,
 )
 
 
@@ -59,9 +65,11 @@ from preliz.distributions import (
         (Laplace, (0, 2)),
         (Logistic, (0, 1)),
         (LogNormal, (0, 1)),
+        (LogitNormal, (0, 0.5)),
         (Moyal, (0, 2)),
         (Normal, (0, 1)),
         (Pareto, (5, 1)),
+        (Rice, (0, 2)),
         (SkewNormal, (0, 1, 6)),
         (Student, (4, 0, 1)),
         (Triangular, (0, 2, 4)),
@@ -70,10 +78,20 @@ from preliz.distributions import (
         (VonMises, (1, 2)),
         (Wald, (2, 1)),
         (Weibull, (2, 1)),
+        (Bernoulli, (0.5,)),
+        (BetaBinomial, (1, 2, 10)),
         (Binomial, (5, 0.5)),
         (DiscreteUniform, (-2, 2)),
+        (Geometric, (0.75,)),
         (NegativeBinomial, (10, 0.5)),
         (Poisson, (4.2,)),
+        (
+            ZeroInflatedPoisson,
+            (
+                0.8,
+                4.2,
+            ),
+        ),
     ],
 )
 def test_auto_recover(distribution, params):
