@@ -15,10 +15,13 @@ def two_dist():
     "kwargs",
     [
         {},
-        {"moments": "mdsk", "legend": False},
-        {"moments": "mdsk", "legend": True},
+        {"moments": "mdsk"},
+        {"moments": "mdsk", "legend": "title"},
         {"pointinterval": True},
-        {"quantiles": [0.25, 0.5, 0.75]},
+        {"pointinterval": True, "levels": [0.1, 0.9]},
+        {"pointinterval": True, "interval": "eti", "levels": [0.9]},
+        {"pointinterval": True, "interval": "quantiles"},
+        {"pointinterval": True, "interval": "quantiles", "levels": [0.1, 0.5, 0.9]},
         {"support": "restricted"},
         {"figsize": (4, 4)},
         {"ax": plt.subplots()[1]},
